aboutsummaryrefslogtreecommitdiffstats
path: root/examples/stub.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/stub.py')
-rw-r--r--examples/stub.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/stub.py b/examples/stub.py
index 10b34283..614acee2 100644
--- a/examples/stub.py
+++ b/examples/stub.py
@@ -4,11 +4,11 @@ import mitmproxy
"""
-def start():
+def configure(options):
"""
Called once on script startup, before any other events.
"""
- mitmproxy.ctx.log("start")
+ mitmproxy.ctx.log("configure")
def clientconnect(root_layer):
@@ -4,11 +4,11 @@ import mitmproxy
"""
- Called once on script startup, before any other events.
+ Called once on script startup before any other events, and whenever options changes.
"""